function usage{
  Write-Host ''
  Write-Host '  usage:'
  Write-Host '    .\proxy_config.ps1 [enable/disable] <proxy_string>'
  Write-Host '      <proxy_string>: eg, username:password@proxy.example.com:8080'
  Write-Host ''
  exit 1
}
if ($Args[0] -eq $null -or $Args[0] -ne 'disable' -and $Args[0] -ne 'enable') {
  usage
}
if ($Args[0] -eq 'enable') {
  if ($Args[1] -eq $null) {
    usage
  }
}
if (!(Test-Path "$pwd\config.xml")) {
  Write-Host "config.xml File Not Found, Run .\generate_config.ps1 before."
  exit 1
}
$config = Import-Clixml -LiteralPath config.xml

$api_url = $config.api_url
$hostname = $config.hostname
$base_path = $config.base_path
$register_apikey = $config.register_apikey
$host_apikey = $config.host_apikey
$proxy = $Args[0]

if ($Args[1] -ne $null) {
  $proxy_url_string = 'http://'+$Args[1]
  try {
    $proxy_url = [uri]$proxy_url_string
  } catch {
    Write-Host ''
    Write-Host '  Invalid proxy URL.'
    usage
  }
  $proxy_host = $proxy_url.Host
  $proxy_port = $proxy_url.Port

  if ($proxy_url.UserInfo -ne '') {
    $auth = $proxy_url.UserInfo -split ':'
    $proxy_user = $auth[0]
    $proxy_pass = $auth[1]
  } else {
    $proxy_user = ''
    $proxy_pass = ''
  }
} else {
  $proxy_host = ''
  $proxy_port = ''
  $proxy_user = ''
  $proxy_pass = ''
}

@{api_url=$api_url;
  hostname=$hostname;
  base_path=$base_path;
  register_apikey=$register_apikey;
  host_apikey=$host_apikey;
  proxy=$proxy;
  proxy_host=$proxy_host;
  proxy_port=$proxy_port;
  proxy_user=$proxy_user;
  proxy_pass=$proxy_pass;
 }| Export-Clixml -LiteralPath config.xml

